@@ -4,6 +4,7 @@ use crate::utilsmod::*;
 
 #[allow(unused_imports)]
 use ansi_term::Colour::{Green, Yellow};
+use regex::Regex;
 use std::fs::File;
 use std::io::{BufRead, BufReader};
 use std::{env, fs, path::Path};
@@ -152,14 +153,60 @@ pub fn workspace_or_project_count_lines() -> LinesOfCode {
 }
 
 /// markdown can have nice tables
-pub fn as_md_table(lines_of_code:LinesOfCode)->String{
-    format!("
+pub fn as_md_table(lines_of_code: &LinesOfCode) -> String {
+    // I added an empty row to have the next row with different color from the header.
+    format!(
+        "
 | src code | doc comments | comments | examples | tests |
 | :------: | :----------: | :------: | :------: | :---: |
-| {:^8   } | {:^12      } | {:^8   } | {:^8   } | {:^5} |",
-lines_of_code.src_code_lines,
-lines_of_code.src_doc_comment_lines,
-lines_of_code.src_comment_lines,
-lines_of_code.examples_lines,
-lines_of_code.tests_lines)
-}
\ No newline at end of file
+|  lines   |     lines    |   lines  |   lines  | lines |
+| {:^8   } | {:^12      } | {:^8   } | {:^8   } | {:^5} |
+
+",
+        lines_of_code.src_code_lines,
+        lines_of_code.src_doc_comment_lines,
+        lines_of_code.src_comment_lines,
+        lines_of_code.examples_lines,
+        lines_of_code.tests_lines
+    )
+}
+pub fn as_shield_badges(lines_of_code: &LinesOfCode) -> String {
+    // find the repo name
+    // $ git remote -v
+    // returns
+    // origin  git@github.com:LucianoBestia/lmake_lines_of_code.git (fetch)
+    let output = std::process::Command::new("git")
+        .arg("remote")
+        .arg("-v")
+        .output()
+        .unwrap();
+    let output = String::from_utf8_lossy(&output.stdout);
+
+    // regex capture 3 groups: website, user_name and repo_name
+    let reg = unwrap!(Regex::new(r#"@(.*?):(.*?)/(.*?).git"#));
+    let cap = unwrap!(reg.captures(&output));
+    let link = format!("https://{}/{}/{}/", &cap[1], &cap[2], &cap[3]);
+
+    let src_code_lines = format!(
+        "[![Lines in Rust code](https://img.shields.io/badge/Lines_in_Rust-{}-green.svg)]({})",
+        lines_of_code.src_code_lines, link
+    );
+    let src_doc_comment_lines = format!("[![Lines in Doc comments](https://img.shields.io/badge/Lines_in_Doc_comments-{}-blue.svg)]({})",lines_of_code.src_doc_comment_lines,link);
+    let src_comment_lines = format!(
+        "[![Lines in Comments](https://img.shields.io/badge/Lines_in_comments-{}-purple.svg)]({})",
+        lines_of_code.src_comment_lines, link
+    );
+    let example_lines = format!(
+        "[![Lines in examples](https://img.shields.io/badge/Lines_in_examples-{}-yellow.svg)]({})",
+        lines_of_code.examples_lines, link
+    );
+    let tests_lines = format!(
+        "[![Lines in tests](https://img.shields.io/badge/Lines_in_tests-{}-orange.svg)]({})",
+        lines_of_code.tests_lines, link
+    );
+    //return
+    format!(
+        "{}\n{}\n{}\n{}\n{}\n",
+        src_code_lines, src_doc_comment_lines, src_comment_lines, example_lines, tests_lines
+    )
+}
